darkhistory.history.reionization.coll_ion_rate — DarkHistory documentation

# darkhistory.history.reionization.coll_ion_rate

`darkhistory.history.reionization.` `coll_ion_rate`(species, T_m)

  Collisional ionization rate.

  Parameters: | species : {‘HI’, ‘HeI’, ‘HeII’} Species of interest. T_m : float Matter temperature in eV.
  Returns: | float Collisional ionization rate in s^-1. See astro-ph/0607331.

#### Previous topic

darkhistory.history.reionization.coll_ion_cooling_rate

#### Next topic

darkhistory.history.reionization.photoheat_rate

### This Page

Show Source